@@ -369,6 +369,13 @@ func NewServer(opts ServerOpts) *Server {
 			}
 			return executeCommandNew(nb, server.documents, context, params.Arguments)
 
+		case cmdLink:
+			nb, err := openNotebook()
+			if err != nil {
+				return nil, err
+			}
+			return executeCommandLink(nb, server.documents, context, params.Arguments)
+
 		case cmdList:
 			nb, err := openNotebook()
 			if err != nil {
@@ -421,6 +428,7 @@ func NewServer(opts ServerOpts) *Server {
 				Title: actionTitle,
 				Kind:  stringPtr(protocol.CodeActionKindRefactor),
 				Command: &protocol.Command{
+					Title:     actionTitle,
 					Command:   cmdNew,
 					Arguments: []interface{}{wd, jsonOpts},
 				},
