@@ -12,19 +12,23 @@ import (
 
 // Config holds the user configuration.
 type Config struct {
-	Note    NoteConfig
-	Groups  map[string]GroupConfig
-	Format  FormatConfig
-	Tool    ToolConfig
-	LSP     LSPConfig
-	Filters map[string]string
-	Aliases map[string]string
-	Extra   map[string]string
+	Notebook NotebookConfig
+	Note     NoteConfig
+	Groups   map[string]GroupConfig
+	Format   FormatConfig
+	Tool     ToolConfig
+	LSP      LSPConfig
+	Filters  map[string]string
+	Aliases  map[string]string
+	Extra    map[string]string
 }
 
 // NewDefaultConfig creates a new Config with the default settings.
 func NewDefaultConfig() Config {
 	return Config{
+		Notebook: NotebookConfig{
+			Dir: opt.NullString,
+		},
 		Note: NoteConfig{
 			FilenameTemplate: "{{id}}",
 			Extension:        "md",
@@ -36,7 +40,7 @@ func NewDefaultConfig() Config {
 				Length:  4,
 				Case:    CaseLower,
 			},
-			Ignore: []string{},
+			Exclude: []string{},
 		},
 		Groups: map[string]GroupConfig{},
 		Format: FormatConfig{
@@ -148,6 +152,7 @@ type MarkdownConfig struct {
 // ToolConfig holds the external tooling configuration.
 type ToolConfig struct {
 	Editor     opt.String
+	Shell      opt.String
 	Pager      opt.String
 	FzfPreview opt.String
 	FzfLine    opt.String
@@ -191,6 +196,11 @@ const (
 	LSPDiagnosticHint    LSPDiagnosticSeverity = 4
 )
 
+// NotebookConfig holds configuration about the default notebook
+type NotebookConfig struct {
+	Dir opt.String
+}
+
 // NoteConfig holds the user configuration used when generating new notes.
 type NoteConfig struct {
 	// Handlebars template used when generating a new filename.
@@ -206,7 +216,7 @@ type NoteConfig struct {
 	// Settings used when generating a random ID.
 	IDOptions IDOptions
 	// Path globs to ignore when indexing notes.
-	Ignore []string
+	Exclude []string
 }
 
 // GroupConfig holds the user configuration for a given group of notes.
@@ -216,16 +226,16 @@ type GroupConfig struct {
 	Extra map[string]string
 }
 
-// IgnoreGlobs returns all the Note.Ignore path globs for the group paths,
+// ExcludeGlobs returns all the Note.Exclude path globs for the group paths,
 // relative to the root of the notebook.
-func (c GroupConfig) IgnoreGlobs() []string {
+func (c GroupConfig) ExcludeGlobs() []string {
 	if len(c.Paths) == 0 {
-		return c.Note.Ignore
+		return c.Note.Exclude
 	}
 
 	globs := []string{}
 	for _, p := range c.Paths {
-		for _, g := range c.Note.Ignore {
+		for _, g := range c.Note.Exclude {
 			globs = append(globs, filepath.Join(p, g))
 		}
 	}
@@ -248,7 +258,7 @@ func (c GroupConfig) Clone() GroupConfig {
 
 // OpenConfig creates a new Config instance from its TOML representation stored
 // in the given file.
-func OpenConfig(path string, parentConfig Config, fs FileStorage) (Config, error) {
+func OpenConfig(path string, parentConfig Config, fs FileStorage, isGlobal bool) (Config, error) {
 	// The local config is optional.
 	exists, err := fs.FileExists(path)
 	if err == nil && !exists {
@@ -260,7 +270,7 @@ func OpenConfig(path string, parentConfig Config, fs FileStorage) (Config, error
 		return parentConfig, errors.Wrapf(err, "failed to open config file at %s", path)
 	}
 
-	return ParseConfig(content, path, parentConfig)
+	return ParseConfig(content, path, parentConfig, isGlobal)
 }
 
 // ParseConfig creates a new Config instance from its TOML representation.
@@ -268,7 +278,7 @@ func OpenConfig(path string, parentConfig Config, fs FileStorage) (Config, error
 // for templates.
 //
 // The parentConfig will be used to inherit default config settings.
-func ParseConfig(content []byte, path string, parentConfig Config) (Config, error) {
+func ParseConfig(content []byte, path string, parentConfig Config, isGlobal bool) (Config, error) {
 	wrap := errors.Wrapperf("failed to read config")
 
 	config := parentConfig
@@ -279,6 +289,16 @@ func ParseConfig(content []byte, path string, parentConfig Config) (Config, erro
 		return config, wrap(err)
 	}
 
+	// Notebook
+	notebook := tomlConf.Notebook
+	if notebook.Dir != "" {
+		if isGlobal {
+			config.Notebook.Dir = opt.NewNotEmptyString(notebook.Dir)
+		} else {
+			return config, wrap(errors.New("notebook.dir should not be set on local configuration"))
+		}
+	}
+
 	// Note
 	note := tomlConf.Note
 	if note.Filename != "" {
@@ -305,8 +325,11 @@ func ParseConfig(content []byte, path string, parentConfig Config) (Config, erro
 	if note.DefaultTitle != "" {
 		config.Note.DefaultTitle = note.DefaultTitle
 	}
+	for _, v := range note.Exclude {
+		config.Note.Exclude = append(config.Note.Exclude, v)
+	}
 	for _, v := range note.Ignore {
-		config.Note.Ignore = append(config.Note.Ignore, v)
+		config.Note.Exclude = append(config.Note.Exclude, v)
 	}
 	if tomlConf.Extra != nil {
 		for k, v := range tomlConf.Extra {
@@ -355,6 +378,9 @@ func ParseConfig(content []byte, path string, parentConfig Config) (Config, erro
 	if tool.Editor != nil {
 		config.Tool.Editor = opt.NewNotEmptyString(*tool.Editor)
 	}
+	if tool.Shell != nil {
+		config.Tool.Shell = opt.NewNotEmptyString(*tool.Shell)
+	}
 	if tool.Pager != nil {
 		config.Tool.Pager = opt.NewStringWithPtr(tool.Pager)
 	}
@@ -454,8 +480,11 @@ func (c GroupConfig) merge(tomlConf tomlGroupConfig, name string) GroupConfig {
 	if note.DefaultTitle != "" {
 		res.Note.DefaultTitle = note.DefaultTitle
 	}
+	for _, v := range note.Exclude {
+		res.Note.Exclude = append(res.Note.Exclude, v)
+	}
 	for _, v := range note.Ignore {
-		res.Note.Ignore = append(res.Note.Ignore, v)
+		res.Note.Exclude = append(res.Note.Exclude, v)
 	}
 	if tomlConf.Extra != nil {
 		for k, v := range tomlConf.Extra {
@@ -468,14 +497,19 @@ func (c GroupConfig) merge(tomlConf tomlGroupConfig, name string) GroupConfig {
 
 // tomlConfig holds the TOML representation of Config
 type tomlConfig struct {
-	Note    tomlNoteConfig
-	Groups  map[string]tomlGroupConfig `toml:"group"`
-	Format  tomlFormatConfig
-	Tool    tomlToolConfig
-	LSP     tomlLSPConfig
-	Extra   map[string]string
-	Filters map[string]string `toml:"filter"`
-	Aliases map[string]string `toml:"alias"`
+	Notebook tomlNotebookConfig
+	Note     tomlNoteConfig
+	Groups   map[string]tomlGroupConfig `toml:"group"`
+	Format   tomlFormatConfig
+	Tool     tomlToolConfig
+	LSP      tomlLSPConfig
+	Extra    map[string]string
+	Filters  map[string]string `toml:"filter"`
+	Aliases  map[string]string `toml:"alias"`
+}
+
+type tomlNotebookConfig struct {
+	Dir string
 }
 
 type tomlNoteConfig struct {
@@ -487,7 +521,8 @@ type tomlNoteConfig struct {
 	IDCharset    string   `toml:"id-charset"`
 	IDLength     int      `toml:"id-length"`
 	IDCase       string   `toml:"id-case"`
-	Ignore       []string `toml:"ignore"`
+	Exclude      []string `toml:"exclude"`
+	Ignore      []string `toml:"ignore"` // Legacy alias to `exclude`
 }
 
 type tomlGroupConfig struct {
@@ -511,6 +546,7 @@ type tomlMarkdownConfig struct {
 
 type tomlToolConfig struct {
 	Editor     *string
+	Shell      *string
 	Pager      *string
 	FzfPreview *string `toml:"fzf-preview"`
 	FzfLine    *string `toml:"fzf-line"`
