@@ -10,10 +10,13 @@ import (
 )
 
 func TestParseDefaultConfig(t *testing.T) {
-	conf, err := ParseConfig([]byte(""), ".zk/config.toml", NewDefaultConfig())
+	conf, err := ParseConfig([]byte(""), ".zk/config.toml", NewDefaultConfig(), true)
 
 	assert.Nil(t, err)
 	assert.Equal(t, conf, Config{
+		Notebook: NotebookConfig{
+			Dir: opt.NullString,
+		},
 		Note: NoteConfig{
 			FilenameTemplate: "{{id}}",
 			Extension:        "md",
@@ -25,7 +28,7 @@ func TestParseDefaultConfig(t *testing.T) {
 			},
 			DefaultTitle: "Untitled",
 			Lang:         "en",
-			Ignore:       []string{},
+			Exclude:      []string{},
 		},
 		Groups: make(map[string]GroupConfig),
 		Format: FormatConfig{
@@ -40,6 +43,7 @@ func TestParseDefaultConfig(t *testing.T) {
 		},
 		Tool: ToolConfig{
 			Editor:     opt.NullString,
+			Shell:      opt.NullString,
 			Pager:      opt.NullString,
 			FzfPreview: opt.NullString,
 			FzfLine:    opt.NullString,
@@ -57,7 +61,7 @@ func TestParseDefaultConfig(t *testing.T) {
 }
 
 func TestParseInvalidConfig(t *testing.T) {
-	_, err := ParseConfig([]byte(`;`), ".zk/config.toml", NewDefaultConfig())
+	_, err := ParseConfig([]byte(`;`), ".zk/config.toml", NewDefaultConfig(), false)
 	assert.NotNil(t, err)
 }
 
@@ -65,6 +69,9 @@ func TestParseComplete(t *testing.T) {
 	conf, err := ParseConfig([]byte(`
 		# Comment
 
+		[notebook]
+		dir = "~/notebook"
+
 		[note]
 		filename = "{{id}}.note"
 		extension = "txt"
@@ -74,7 +81,7 @@ func TestParseComplete(t *testing.T) {
 		id-charset = "alphanum"
 		id-length = 4
 		id-case = "lower"
-		ignore = ["ignored", ".git"]
+		exclude = ["ignored", ".git"]
 
 		[format.markdown]
 		hashtags = false
@@ -86,6 +93,7 @@ func TestParseComplete(t *testing.T) {
 
 		[tool]
 		editor = "vim"
+		shell = "/bin/bash"
 		pager = "less"
 		fzf-preview = "bat {1}"
 		fzf-line = "{{title}}"
@@ -116,7 +124,7 @@ func TestParseComplete(t *testing.T) {
 		id-charset = "letters"
 		id-length = 8
 		id-case = "mixed"
-		ignore = ["new-ignored"]
+		exclude = ["new-ignored"]
 		
 		[group.log.extra]
 		log-ext = "value"
@@ -136,10 +144,13 @@ func TestParseComplete(t *testing.T) {
 		[lsp.diagnostics]
 		wiki-title = "hint"
 		dead-link = "none"
-	`), ".zk/config.toml", NewDefaultConfig())
+	`), ".zk/config.toml", NewDefaultConfig(), true)
 
 	assert.Nil(t, err)
 	assert.Equal(t, conf, Config{
+		Notebook: NotebookConfig{
+			Dir: opt.NewString("~/notebook"),
+		},
 		Note: NoteConfig{
 			FilenameTemplate: "{{id}}.note",
 			Extension:        "txt",
@@ -151,7 +162,7 @@ func TestParseComplete(t *testing.T) {
 			},
 			Lang:         "fr",
 			DefaultTitle: "Sans titre",
-			Ignore:       []string{"ignored", ".git"},
+			Exclude:      []string{"ignored", ".git"},
 		},
 		Groups: map[string]GroupConfig{
 			"log": {
@@ -167,7 +178,7 @@ func TestParseComplete(t *testing.T) {
 					},
 					Lang:         "de",
 					DefaultTitle: "Ohne Titel",
-					Ignore:       []string{"ignored", ".git", "new-ignored"},
+					Exclude:      []string{"ignored", ".git", "new-ignored"},
 				},
 				Extra: map[string]string{
 					"hello":   "world",
@@ -188,7 +199,7 @@ func TestParseComplete(t *testing.T) {
 					},
 					Lang:         "fr",
 					DefaultTitle: "Sans titre",
-					Ignore:       []string{"ignored", ".git"},
+					Exclude:      []string{"ignored", ".git"},
 				},
 				Extra: map[string]string{
 					"hello": "world",
@@ -208,7 +219,7 @@ func TestParseComplete(t *testing.T) {
 					},
 					Lang:         "fr",
 					DefaultTitle: "Sans titre",
-					Ignore:       []string{"ignored", ".git"},
+					Exclude:      []string{"ignored", ".git"},
 				},
 				Extra: map[string]string{
 					"hello": "world",
@@ -228,6 +239,7 @@ func TestParseComplete(t *testing.T) {
 		},
 		Tool: ToolConfig{
 			Editor:     opt.NewString("vim"),
+			Shell:      opt.NewString("/bin/bash"),
 			Pager:      opt.NewString("less"),
 			FzfPreview: opt.NewString("bat {1}"),
 			FzfLine:    opt.NewString("{{title}}"),
@@ -274,7 +286,7 @@ func TestParseMergesGroupConfig(t *testing.T) {
 		id-charset = "letters"
 		id-length = 42
 		id-case = "upper"
-		ignore = ["ignored", ".git"]
+		exclude = ["ignored", ".git"]
 
 		[extra]
 		hello = "world"
@@ -292,7 +304,7 @@ func TestParseMergesGroupConfig(t *testing.T) {
 		log-ext = "value"
 
 		[group.inherited]
-	`), ".zk/config.toml", NewDefaultConfig())
+	`), ".zk/config.toml", NewDefaultConfig(), false)
 
 	assert.Nil(t, err)
 	assert.Equal(t, conf, Config{
@@ -307,7 +319,7 @@ func TestParseMergesGroupConfig(t *testing.T) {
 			},
 			Lang:         "fr",
 			DefaultTitle: "Sans titre",
-			Ignore:       []string{"ignored", ".git"},
+			Exclude:      []string{"ignored", ".git"},
 		},
 		Groups: map[string]GroupConfig{
 			"log": {
@@ -323,7 +335,7 @@ func TestParseMergesGroupConfig(t *testing.T) {
 					},
 					Lang:         "fr",
 					DefaultTitle: "Sans titre",
-					Ignore:       []string{"ignored", ".git"},
+					Exclude:      []string{"ignored", ".git"},
 				},
 				Extra: map[string]string{
 					"hello":   "override",
@@ -344,7 +356,7 @@ func TestParseMergesGroupConfig(t *testing.T) {
 					},
 					Lang:         "fr",
 					DefaultTitle: "Sans titre",
-					Ignore:       []string{"ignored", ".git"},
+					Exclude:      []string{"ignored", ".git"},
 				},
 				Extra: map[string]string{
 					"hello": "world",
@@ -391,7 +403,7 @@ func TestParsePreservePropertiesAllowingEmptyValues(t *testing.T) {
 		[tool]
 		pager = ""
 		fzf-preview = ""
-	`), ".zk/config.toml", NewDefaultConfig())
+	`), ".zk/config.toml", NewDefaultConfig(), false)
 
 	assert.Nil(t, err)
 	assert.Equal(t, conf.Tool.Pager.IsNull(), false)
@@ -400,13 +412,29 @@ func TestParsePreservePropertiesAllowingEmptyValues(t *testing.T) {
 	assert.Equal(t, conf.Tool.FzfPreview, opt.NewString(""))
 }
 
+func TestParseNotebook(t *testing.T) {
+	toml := `
+			[notebook]
+			dir = "/home/user/folder"
+		`
+	// Should parse notebook if isGlobal == true
+	conf, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig(), true)
+	assert.Nil(t, err)
+	assert.Equal(t, conf.Notebook.Dir, opt.NewString("/home/user/folder"))
+
+	// Should not parse notebook if isGlobal == false
+	conf, err = ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig(), false)
+	assert.NotNil(t, err)
+	assert.Err(t, err, "notebook.dir should not be set on local configuration")
+}
+
 func TestParseIDCharset(t *testing.T) {
 	test := func(charset string, expected Charset) {
 		toml := fmt.Sprintf(`
 			[note]
 			id-charset = "%v"
 		`, charset)
-		conf, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig())
+		conf, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig(), false)
 		assert.Nil(t, err)
 		if !cmp.Equal(conf.Note.IDOptions.Charset, expected) {
 			t.Errorf("Didn't parse ID charset `%v` as expected", charset)
@@ -427,7 +455,7 @@ func TestParseIDCase(t *testing.T) {
 			[note]
 			id-case = "%v"
 		`, letterCase)
-		conf, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig())
+		conf, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig(), false)
 		assert.Nil(t, err)
 		if !cmp.Equal(conf.Note.IDOptions.Case, expected) {
 			t.Errorf("Didn't parse ID case `%v` as expected", letterCase)
@@ -448,7 +476,7 @@ func TestParseMarkdownLinkEncodePath(t *testing.T) {
 			[format.markdown]
 			link-format = "%s"
 		`, format)
-		conf, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig())
+		conf, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig(), false)
 		assert.Nil(t, err)
 		assert.Equal(t, conf.Format.Markdown.LinkEncodePath, expected)
 	}
@@ -466,7 +494,7 @@ func TestParseLSPDiagnosticsSeverity(t *testing.T) {
 			wiki-title = "%s"
 			dead-link = "%s"
 		`, value, value)
-		conf, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig())
+		conf, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig(), false)
 		assert.Nil(t, err)
 		assert.Equal(t, conf.LSP.Diagnostics.WikiTitle, expected)
 		assert.Equal(t, conf.LSP.Diagnostics.DeadLink, expected)
@@ -483,35 +511,35 @@ func TestParseLSPDiagnosticsSeverity(t *testing.T) {
 		[lsp.diagnostics]
 		wiki-title = "foobar"
 	`
-	_, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig())
+	_, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig(), false)
 	assert.Err(t, err, "foobar: unknown LSP diagnostic severity - may be none, hint, info, warning or error")
 }
 
-func TestGroupConfigIgnoreGlobs(t *testing.T) {
+func TestGroupConfigExcludeGlobs(t *testing.T) {
 	// empty globs
 	config := GroupConfig{
 		Paths: []string{"path"},
-		Note:  NoteConfig{Ignore: []string{}},
+		Note:  NoteConfig{Exclude: []string{}},
 	}
-	assert.Equal(t, config.IgnoreGlobs(), []string{})
+	assert.Equal(t, config.ExcludeGlobs(), []string{})
 
 	// empty paths
 	config = GroupConfig{
 		Paths: []string{},
 		Note: NoteConfig{
-			Ignore: []string{"ignored", ".git"},
+			Exclude: []string{"ignored", ".git"},
 		},
 	}
-	assert.Equal(t, config.IgnoreGlobs(), []string{"ignored", ".git"})
+	assert.Equal(t, config.ExcludeGlobs(), []string{"ignored", ".git"})
 
 	// several paths
 	config = GroupConfig{
 		Paths: []string{"log", "drafts"},
 		Note: NoteConfig{
-			Ignore: []string{"ignored", "*.git"},
+			Exclude: []string{"ignored", "*.git"},
 		},
 	}
-	assert.Equal(t, config.IgnoreGlobs(), []string{"log/ignored", "log/*.git", "drafts/ignored", "drafts/*.git"})
+	assert.Equal(t, config.ExcludeGlobs(), []string{"log/ignored", "log/*.git", "drafts/ignored", "drafts/*.git"})
 }
 
 func TestGroupConfigClone(t *testing.T) {
@@ -528,7 +556,7 @@ func TestGroupConfigClone(t *testing.T) {
 			},
 			Lang:         "fr",
 			DefaultTitle: "Sans titre",
-			Ignore:       []string{"ignored", ".git"},
+			Exclude:      []string{"ignored", ".git"},
 		},
 		Extra: map[string]string{
 			"hello": "world",
@@ -548,7 +576,7 @@ func TestGroupConfigClone(t *testing.T) {
 	clone.Note.IDOptions.Case = CaseUpper
 	clone.Note.Lang = "de"
 	clone.Note.DefaultTitle = "Ohne Titel"
-	clone.Note.Ignore = []string{"other-ignored"}
+	clone.Note.Exclude = []string{"other-ignored"}
 	clone.Extra["test"] = "modified"
 
 	// Check that we didn't modify the original
@@ -565,7 +593,7 @@ func TestGroupConfigClone(t *testing.T) {
 			},
 			Lang:         "fr",
 			DefaultTitle: "Sans titre",
-			Ignore:       []string{"ignored", ".git"},
+			Exclude:      []string{"ignored", ".git"},
 		},
 		Extra: map[string]string{
 			"hello": "world",
